pub enum Error {
UnableToRetrieveNumCols(Error),
ColumnFailure {
name: String,
index: usize,
source: ColumnFailure,
},
OdbcBufferTooSmall {
max_bytes_per_batch: usize,
bytes_per_row: usize,
},
EncodingInvalid {
source: FromUtf8Error,
},
}Expand description
A variation of things which can go wrong then creating an crate::OdbcReader.
Variants
UnableToRetrieveNumCols(Error)
Failure to retrieve the number of columns from the result set.
ColumnFailure
Indicates that the error is related to a specify column.
OdbcBufferTooSmall
Failure during constructing an OdbcReader, if it turns out the buffer memory size limit is too small.
EncodingInvalid
We expect UTF-8 to be the default on non-windows platforms. Yet still some systems are configured different.
Fields

source: FromUtf8ErrorTrait Implementations
Sourceimpl Error for Error
impl Error for Error
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()